#!/bin/bash

# Author Vladimir Koković (vladimir.kokovic@gmail.com)

set -v
set -e

LOs="/mnt/sdd1/home/src/libreoffice-vk/libreoffice-install/lib/libreoffice"           #master

VCLPLUGINs="gtk3 gen gtk3_kde5 gtk svp kf5 qt5"

JAVA_LOGS=/tmp/test-lo6-dev-only
mkdir -p $JAVA_LOGS

export JAVA_HOME=/usr/lib/jvm/jdk-12
JAVA_ARGS=classic_letter.ott
CNT=0

IFS=' ' # IFS for blank word breaks
for lo in $LOs
do
  lo_ver="master"

  # OBeanPanel is swing component from the Java Libre Office Programming(JLOP Andrew Davison) http://fivedots.coe.psu.ac.th/~ad/jlop/
  # Java LibreOffice Programming (JLOP) is intended for programmers who want to learn how to use the Java version of the LibreOffice API.
  # This allows Java to control and manipulate LibreOffice's text, drawing, presentation, spreadsheet, and database applications,
  # and a lot more (e.g. its spell checker, forms designer, and charting tools).
  # One of my aims(Andrew Davison) was to develop utility code to help flatten the steep learning curve for the API.
  # For example, my Lo class simplifies the steps needed to initialize the API (by creating a connection to a LibreOffice process),
  # to open/create a document, save it, and close down LibreOffice.

  set -e

  # vk current libreoffice
  rm -rf /opt/libreoffice6/program
  ln -s $lo/program /opt/libreoffice6/program

  # vk NetBeans project location
  cd /asoft-src/asoft/test/vk/OBeanPanel
  ant clean jar > $JAVA_LOGS/nblast.log 2>&1

  set +e
  for vp in $VCLPLUGINs
  do
    vplug=$vp
    if [[ $vplug != "" ]]; then
      echo "($lo_ver"-"$vplug"
      export LD_LIBRARY_PATH=$JAVA_HOME/lib:$lo/program
      export SAL_USE_VCLPLUGIN=$vplug
      export UNO_PATH=$lo/program
      /usr/lib/jvm/jdk-12/bin/java -jar "dist/OBeanPanel.jar" $JAVA_ARGS "$lo_ver"-"$vplug" $JAVA_LOGS/$lo_ver"-"$vplug"-spectacle.png " \
      > $JAVA_LOGS/$lo_ver"-"$vplug.log 2>&1
      echo "Java RC=$?)"
    fi
  done
done

exit 0
